# *environ-config*: Application Configuration With Env Variables

Release **{sub-ref}`release`**  ([What's new?](changelog))

```{include} ../README.md
:start-after: <!-- teaser-begin -->
:end-before: <!-- teaser-end -->
```


## User's Guide

```{toctree}
:maxdepth: 2

tutorial
testing
api
```

## Project Information

```{include} ../README.md
:start-after: "## Project Information"
```

### Indices and tables

- {ref}`genindex`
- {ref}`search`

```{toctree}
:hidden: true

changelog
```
